import React, { useRef, useState, useCallback, useEffect } from 'react';
import { CSSTransition } from 'react-transition-group';
import styles from './Dropdown.module.css';

export const Item = ({ value, display, onSelect, children }) => (
  <div className={styles.item} onClick={() => onSelect(value, display ?? value)}>
    {children}
  </div>
);

export const Dropdown = ({ open, onSelect, onClick, children }) => {
  const transitionRef = useRef(null);
  const [ displayed, setDisplayed ] = useState(null);
  const onSelectCallback = useCallback((value, display) => { 
    setDisplayed(display); 
    onSelect(value); 
  }, [onSelect]);
  useEffect(() => {
    if (displayed) {
      return;
    }
    let found = null;
    children.forEach(element => {
      if (!React.isValidElement(element) || found) {
        return;
      }
      if (element.props['default']) {
        const { value, display } = element.props;
        found = display ?? value;
      }
    });
    setDisplayed(found);
  }, [children, displayed])
  return (
    <div className={styles.container}>
      <div className={styles.button} onClick={onClick}>{displayed}</div>
      <CSSTransition nodeRef={transitionRef} in={open} timeout={200} mountOnEnter unmountOnExit classNames={{
        enter: styles['list-enter'],
        enterActive: styles['list-enter-active'],
        exit: styles['list-exit'],
        exitActive: styles['list-exit-active'],
      }}>
        <div className={styles.list} ref={transitionRef}>
          {children.map((child, key) => React.cloneElement(child, { onSelect: onSelectCallback, key }))}
        </div>
      </CSSTransition>
    </div>
  )
};
